<?php
/**
 * This file implements the Image / Blog logo Widget class.
 *
 * This file is part of Quam Plures - {@link http://quamplures.net/}
 * See also {@link https://launchpad.net/quam-plures}.
 *
 * @copyright (c) 2009 - 2011 by the Quam Plures developers - {@link http://quamplures.net/}
 * @copyright (c)2003-2009 by Francois PLANQUE - {@link http://fplanque.net/}
 *
 * {@internal License choice
 * - If you have received this file as part of a package, please find the license.txt file in
 *   the same folder or the closest folder above for complete license terms.
 * - If you have received this file individually (e-g: from http://evocms.cvs.sourceforge.net/)
 *   then you must choose one of the following licenses before using the file:
 *   - GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-license.php
 *   - Mozilla Public License 1.1 (MPL) - http://www.opensource.org/licenses/mozilla1.1.php
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author fplanque: Francois PLANQUE.
 *
 * @package widgets
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

load_class( 'widgets/model/_widget.class.php' );


/**
 * @package widgets
 */
class logo_Widget extends ComponentWidget
{
	/**
	 * Constructor
	 */
	function logo_Widget( $db_row = NULL )
	{
		// Call parent constructor:
		parent::ComponentWidget( $db_row, 'widget', 'logo' );
		$this->widget_name = $this->T_('Image / Blog logo');
		$this->widget_title = '';
		$this->menu_link_options = array(
			'home' => T_('Blog home'),
			'main' => T_('Installation home'),
			'other' => T_('URL from text field')
		);
	}


	/**
	 * Get a very short desc. Used in the widget list.
	 *
	 * MAY be overriden by core widgets. Example: menu link widget.
	 */
	function get_short_desc()
	{
		$this->load_param_array();
		if( ! empty( $this->param_array['logo_file'] ) )
		{
			return $this->param_array['logo_file'];
		}
		else
		{
			return $this->get_name();
		}
	}


  /**
	 * Get short description
	 */
	function get_desc()
	{
		return $this->T_('Include an image/logo from the blog\'s file root.');
	}


	/**
	 * Get definitions for editable params
	 *
	 * @see Plugin::GetDefaultSettings()
	 * @param local params like 'for_editing' => true
	 */
	function get_param_definitions( $params )
	{
		$r = array_merge( array(
				'logo_file' => array(
					'label' => $this->T_('Image filename'),
					'note' => $this->T_('The image/logo file must be uploaded to the root of the Blog\'s media dir'),
					'defaultvalue' => 'logo.png',
					'valid_pattern' => array(
						'pattern'=>'^[a-z0-9_\-][a-z0-9_.\-]*$i',
						'error'=>T_('Invalid filename.')
					),
				),
				'link_to' => array(
					'label' => T_('Link to'),
					'type' => 'select',
					'options' => $this->menu_link_options,
					'defaultvalue' => 'home',
					'note' => T_('What do you want to link to?'),
				),
				'other_url' => array(
					'label' => T_('Other URL'),
					'note' => T_('for when you select "URL from text field" above'),
					'defaultvalue' => 'http://',
				),
				'other_title' => array(
					'label' => T_('Other URL title'),
					'note' => T_('for when you select "URL from text field" above'),
					'defaultvalue' => '',
				),
			), parent::get_param_definitions( $params ) );
		return $r;
	}


	/**
	 * Display the widget!
	 *
	 * @param array MUST contain at least the basic display params
	 */
	function display( $params )
	{
		global $app_baseurl;
		global $Blog;

		$this->init_display( $params );

		switch( $this->disp_params['link_to'] )
		{
			case 'home':
			$alt_text = $Blog->dget( 'name', 'htmlattr' );
			$link_value = '<a href="'.$Blog->get( 'url', 'raw' ).'" title="'.$alt_text.'">';
			break;

			case 'main':
			$alt_text = T_('visit this site\'s home page');
			$link_value = '<a href="'.$app_baseurl.'" title="'.$alt_text.'">';
			break;

			case 'other':
			$alt_text = $this->disp_params['other_title'];
			$link_value = '<a href="'.$this->disp_params['other_url'].'" title="'.$alt_text.'">';
			break;
		}

		echo $this->disp_params['block_start'];
		$this->disp_title();
		echo $link_value.'<img src="'.$Blog->get_media_url().$this->disp_params['logo_file'].'" alt="'.$alt_text.'" /></a>';
		echo $this->disp_params['block_end'];
		return true;

	}

}

?>
