<?php
/**
 * This file implements the Single Item Widget class.
 *
 * This file is part of the QuamPlures framework - {@link http://quamplures.net/}
 *
 * @copyright (c)2009 by QuamPlures - {@link http://quamplures.net/}
 *
 * {@internal License choice
 * - If you have received this file as part of a package, please find the license.txt file in
 *   the same folder or the closest folder above for complete license terms.
 * - If you have received this file individually
 *   then you must choose one of the following licenses before using the file:
 *   - GNU General Public License 2 (GPL) - http://www.opensource.org/licenses/gpl-license.php
 *   - Mozilla Public License 1.1 (MPL) - http://www.opensource.org/licenses/mozilla1.1.php
 * }}
 *
 * {@internal Below is a list of authors who have contributed to design/coding of this file: }}
 * @author yabs.
 *
 * @package widgets
 */
if( !defined('QP_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

load_class( 'widgets/model/_widget.class.php' );


/**
 * @package widgets
 */
class single_item_Widget extends ComponentWidget
{
	/**
	 * Constructor
	 */
	function single_item_Widget( $db_row = NULL )
	{
		// Call parent constructor:
		parent::ComponentWidget( $db_row, 'widget', 'single_item' );

		$this->widget_name = $this->T_('Single Item widget');
		$this->widget_title = '';
	}


	/**
	 * Get a very short desc. Used in the widget list.
	 */
	function get_short_desc()
	{
		return format_to_output( $this->disp_params['widget_title'] );
	}


  /**
	 * Get short description
	 */
	function get_desc()
	{
		return $this->T_('Display a link to a single item');
	}


	/**
	 * Get definitions for editable params
	 *
	 * @see Plugin::GetDefaultSettings()
	 * @param local params like 'for_editing' => true
	 */
	function get_param_definitions( $params )
	{
		$r = array_merge( array(
				'item_ID' => array(
					'label' => $this->T_('Item'),
					'note' => $this->T_('ID of the post/item to link'),
					'size' => 4,
				),
				'item_markup' => array(
					'label' => $this->T_('Item markup'),
					'type' => 'select',
					'options' => array(
						'p' => 'P',
						'h1' => 'H1',
						'h2' => 'H2',
						'h3' => 'H3',
						'h4' => 'H4',
						'h5' => 'H5',
						'h6' => 'H6',
						'none' => $this->T_('none'),
					),
					'note' => $this->T_('HTML markup for the item title'),
					'defaultvalue' => 'h3',
				),
				'link_text' => array(
					'label' => T_('Link text'),
					'note' => T_('leave blank for item\'s title'),
					'defaultvalue' => '',
				),
				'link_title' => array(
					'label' => T_('Link title'),
					'defaultvalue' => T_('this is a link to an important article'),
				),
				'show_excerpt' => array(
					'type' => 'checkbox',
					'label' => $this->T_('Show excerpt'),
					'defaultvalue' => 0,
					'note' => $this->T_('check to display an excerpt of the item'),
				),
				'excerpt_markup' => array(
					'label' => $this->T_('Excerpt markup'),
					'type' => 'select',
					'options' => array(
						'p' => 'P',
						'h1' => 'H1',
						'h2' => 'H2',
						'h3' => 'H3',
						'h4' => 'H4',
						'h5' => 'H5',
						'h6' => 'H6',
						'none' => $this->T_('none'),
					),
					'note' => $this->T_('HTML markup for the item excerpt'),
					'defaultvalue' => 'default',
				),
			), parent::get_param_definitions( $params ) );

		return $r;
	}


	/**
	 * Display the widget!
	 *
	 * @param array MUST contain at least the basic display params
	 */
	function display( $params )
	{
		$this->init_display( $params );

		if( $this->disp_params['item_ID'] == '' )
		{
			return;
		}

		$ItemCache = & get_Cache( 'ItemCache' );
		$Item = & $ItemCache->get_by_ID( $this->disp_params['item_ID'], false );

		// are we using a different text?
		$text = $Item->title;
		if( $this->disp_params['link_text'] != '' )
		{
			$text = $this->disp_params['link_text'];
		}
		// create a link even though it ain't done
		$linked_text = '<a href="'.$Item->get_permanent_url().'" title="'.$this->disp_params['link_title'].'">'.$text.'</a>';
		$pre_text = '';
		$post_text = '';
		if( $this->disp_params['item_markup'] != 'none' )
		{
			$pre_text = '<'.$this->disp_params['item_markup'].'>';
			$post_text = '</'.$this->disp_params['item_markup'].'>';
		}

		// start the output process...
		echo $this->disp_params['block_start'];
		// display a title if we have one
		$this->disp_title();
		// display the linked item
		echo $pre_text.$linked_text.$post_text;

		// now for the excerpt, if desired
		if( $this->disp_params['show_excerpt'] )
		{
			$pre_excerpt = '';
			$post_excerpt = '';
			if( $this->disp_params['excerpt_markup'] != 'none' )
			{
				$pre_excerpt = '<'.$this->disp_params['excerpt_markup'].'>';
				$post_excerpt = '</'.$this->disp_params['excerpt_markup'].'>';
			}
			echo $pre_excerpt.$Item->excerpt.$post_excerpt;
		}

		// close the block
		echo $this->disp_params['block_end'];
	}

}

?>
